﻿-------------------------------------------
-- 최종수정 : 2021/09/05

-- 각종 필터링 정보를 담고 있는 파일입니다.
-- 패치로 새로운 던전이 추가되거나 난이도가 추가될 경우 이 파일에서 수정하시면 됩니다.
-- 난이도 추가시에는 FindParty.lua 파일에서 별도 처리가 필요할 수도 있습니다.

-- ===============================
-- 난이도 분류 키워드를 정의합니다.
-- dbname은 실제로 애드온에서 인식하는 명칭이며, name은 던전 필터에 표시되는 이름입니다.
-- keywords는 파티모집 문구에 해당 문자열이 있을 경우 해당 난이도로 분류할 수 있도록 정의하는 부분입니다.

FP_DIFFICULTY_KEYWORDS = {
	[1] = {
		name = "영웅",
		dbname = "heroic",
		keywords = {"영웅", "영던", "0던", "(0)"},
	},
	[2] = {
		name = "일반",
		dbname = "normal",
		keywords = {"일반", "일던", "(1)"},
	},
}

-- ==============================
-- 던전 분류 키워드를 정의합니다.
-- 아래 모든 필드가 있어야합니다.
-- category는 새로운 분류를 추가할 때 이용하시면 됩니다.
-- name은 던전 이름을 입력하며, 낮은 번호가 우선으로 인식됩니다. 번호가 중복되지 않도록 하여주시기 바랍니다.
-- size는 해당 던전의 종류입니다. FindParty.lua 파일내 FP_Category_Color의 테이블 이름에 맞게 입력하셔야 합니다.
-- difficulty는 던전의 난이도입니다. 영던이 있을 경우 테이블에 heroic 문자열을 넣어야 인식합니다.
-- keywords는 파티모집 문구에 해당 문자열이 있을 경우 해당 난이도로 분류할 수 있도록 정의하는 부분입니다.
-- excludekeywords는 던전으로 인식되지 않을 키워드를 정의합니다. 다른 던전과 키워드가 겹칠때 사용합니다.

FP_DUNGEON_KEYWORDS = {
	[1] = {
		category = "불타는 성전 공격대",
		dungeon = {
			[1] = {
				name = "태양샘 고원",
				size = "raid25",
				difficulty = {"normal"},
				keywords = {"태양샘", "태샘"},
			},
			[2] = {
				name = "검은 사원",
				size = "raid25",
				difficulty = {"normal"},
				keywords = {"검사"},
				excludekeywords = {"안퀴"},
			},
			[3] = {
				name = "하이잘 정상",
				size = "raid25",
				difficulty = {"normal"},
				keywords = {"하이잘"},
			},
			[4] = {
				name = "폭풍우 요새",
				size = "raid25",
				difficulty = {"normal"},
				keywords = {"폭요", "폭풍우"},
				excludekeywords = {"퀘"},
			},
			[5] = {
				name = "불뱀 제단",
				size = "raid25",
				difficulty = {"normal"},
				keywords = {"불뱀", "제단"},
				excludekeywords = {"퀘"},
			},
			[6] = {
				name = "그룰의 둥지",
				size = "raid25",
				difficulty = {"normal"},
				keywords = {"그룰", "그롤"},
				excludekeywords = {"대학살", "그룰록"},
			},
			[7] = {
				name = "마그테리돈의 둥지",
				size = "raid25",
				difficulty = {"normal"},
				keywords = {"마그"},
				excludekeywords = {"마그고크"},
			},
			[8] = {
				name = "줄아만",
				size = "raid10",
				difficulty = {"normal"},
				keywords = {"줄아만"},
			},
			[9] = {
				name = "카라잔",
				size = "raid10",
				difficulty = {"normal"},
				keywords = {"카라잔", "정문", "후문"},
				excludekeywords = {"솔름", "솔룸", "솔롬", "솔륨", "스솔", "퀘"},
			},
		},
	},
	[2] = {
		category = "불타는 성전 던전",
		dungeon = {
			[1] = {
				name = "무작위 5인 던전",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"랜덤", "랜영", "무작던전", "무작영던", "무작영웅", "영던스핀", "무작스핀"},
				heroickeywords = {"랜영", "무작영던", "무작영웅", "영던스핀"},
			},
			[2] = {
				name = "마법학자의 정원",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"마법학자", "마정"},
				excludekeywords = {"신록"},
			},
			[3] = {
				name = "메카나르",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"메카"},
			},
			[4] = {
				name = "알카트라즈",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"알카"},
			},
			[5] = {
				name = "신록의 정원",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"신록", "정원"},
				excludekeywords = {"마법학자"},
			},
			[6] = {
				name = "어둠의 미궁",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"미궁"},
			},
			[7] = {
				name = "세데크 전당",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"세데크", "세덱", "안주", "전당"},
			},
			[8] = {
				name = "아키나이 납골당",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"납골당", "납골"},
			},
			[9] = {
				name = "마나 무덤",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"마나", "무덤", "마나무덤"},
				excludekeywords = {"괴철로"},
			},
			[10] = {
				name = "증기 저장고",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"증기", "저장고", "저장소"},
			},
			[11] = {
				name = "지하 수렁",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"수렁"},
			},
			[12] = {
				name = "강제 노역소",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"노역소", "노역", "강노"},
			},
			[13] = {
				name = "으스러진 손의 전당",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"으스", "으손", "으스스"},
				excludekeywords = {"열쇠", "절단기"},
			},
			[14] = {
				name = "피의 용광로",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"피용", "용광로"},
			},
			[15] = {
				name = "지옥불 성루",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"지옥불", "성루"},
			},
			[16] = {
				name = "검은늪",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"검은늪", "검늪"},
			},
			[17] = {
				name = "옛 힐스브래드 구릉지",
				size = "dungeon",
				difficulty = {"heroic", "normal"},
				keywords = {"힐스", "옛힐스"},
			},
		},
	},
	[3] = {
		category = "클래식 공격대",
		dungeon = {
			[1] = {
				name = "낙스라마스",
				size = "raid40",
				difficulty = {"normal"},
				keywords = {"낙스"},
			},
			[2] = {
				name = "안퀴라즈 사원",
				size = "raid40",
				difficulty = {"normal"},
				keywords = {"안퀴사원", "안퀴", "사원"},
				excludekeywords = {"폐허", "페허", "가라앉은", "검은"},
			},
			[3] = {
				name = "안퀴라즈 폐허",
				size = "raid20",
				difficulty = {"normal"},
				keywords = {"안퀴폐허", "폐허", "페허"},
			},
			[4] = {
				name = "줄구룹",
				size = "raid20",
				difficulty = {"normal"},
				keywords = {"줄구룹", "줄구릅", "줄구룸"},
			},
			[5] = {
				name = "검은날개 둥지",
				size = "raid40",
				difficulty = {"normal"},
				keywords = {"검둥"},
			},
			[6] = {
				name = "화산 심장부",
				size = "raid40",
				difficulty = {"normal"},
				keywords = {"화산", "화심"},
				excludekeywords = {"하실", "나락", "입장퀘"}, -- 입장퀘 필터링
			},
			[7] = {
				name = "오닉시아",
				size = "raid40",
				difficulty = {"normal"},
				keywords = {"오닉"},
				excludekeywords = {"하실", "해골", "윈저", "나락", "오닉퀘", "입장퀘"}, -- 입장퀘 필터링
			},
		},
	},
	[4] = {
		category = "클래식 던전",
		dungeon = {
			[1] = {
				name = "가시덩굴 구릉",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"구릉", "구렁", "구룽"},
			},
			[2] = {
				name = "가시덩굴 우리",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"우리"},
				excludekeywords = {"마우리"},
			},
			[3] = {
				name = "검은심연의 나락",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"심연", "검은심연", "검은심연의"},
				excludekeywords = {"바위", "심연의홀", "홀"},
			},
			[4] = {
				name = "검은바위 나락",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"나락", "윈저"},
				excludekeywords = {"심연"},
			},
			[5] = {
				name = "검은바위 첨탑 하층",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"하층"},
			},
			[6] = {
				name = "검은바위 첨탑 상층",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"상층", "드라키"},
			},
			[7] = {
				name = "그림자송곳니 성채",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"그송", "송곳니", "성채"},
			},
			[8] = {
				name = "놈리건",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"놈리"},
			},
			[9] = {
				name = "마라우돈",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"마라우돈", "우동", "마라"},
			},
			[10] = {
				name = "붉은십자군 수도원",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"십자군", "수도원"},
				excludekeywords = {"진홍"},
			},
			[11] = {
				name = "성난불길 협곡",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"성난불길", "성불"},
			},
			[12] = {
				name = "스톰윈드 지하감옥",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"감옥"},
			},
			[13] = {
				name = "스칼로맨스",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"스칼", "교장"},
			},
			[14] = {
				name = "스트라솔름",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"솔름", "솔룸", "솔륨", "솔롬", "스솔", "남작"},
			},
			[15] = {
				name = "아탈학카르 신전",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"학카르", "학칼", "아탈", "가라앉은"},
			},
			[16] = {
				name = "울다만",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"울다"},
			},
			[17] = {
				name = "죽음의 폐광",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"폐광"},
			},
			[18] = {
				name = "줄파락",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"줄파"},
			},
			[19] = {
				name = "통곡의 동굴",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"통곡"},
			},
			[20] = {
				name = "혈투의 전장",
				size = "dungeon",
				difficulty = {"normal"},
				keywords = {"혈투", "혈장"},
			},
		},
	},
	[5] = {
		category = "PvP",
		dungeon = {
			[1] = {
				name = "투기장",
				size = "pvp",
				difficulty = {"normal"},
				keywords = {"투기장", "투기", "점먹", "8승", "10승", "2V2", "2VS2", "2대2", "3V3", "3VS3", "3대3","5V5", "5VS5", "5대5", "2:2", "3:3", "5:5"},
				excludekeywords = {"퀘", "쐐기", "길드", "투기장퀘", "나그란드", "나그", "퀘스트", "피의", "투기장:"},
			},
			[2] = {
				name = "전장",
				size = "pvp",
				difficulty = {"normal"},
				keywords = {"명점", "쟁", "전장", "아라시", "알방", "노래방", "토방", "룰방", "분지", "폭눈"},
				excludekeywords = {"퀘", "쐐기", "길드", "하실"},
			},
		},
	},
	[6] = {
		category = "필드보스",
		dungeon = {
			[1] = {
				name = "필드보스",
				size = "field",
				difficulty = {"normal"},
				keywords = {"카자크", "카작", "절단기"},
				excludekeywords = {"폭요", "폭풍우", "지옥절단기"},
			},
			[2] = {
				name = "필드보스 (클래식)",
				size = "field",
				difficulty = {"normal"},
				keywords = {"아주어고스", "4용", "녹용", "녹용팟", "레손", "이손드레", "에메리스", "타에라"},
			},
		}
	},
	[7] = {
		category = "퀘스트",
		dungeon = {
			[1] = {
				name = "퀘스트",
				size = "quest",
				difficulty = {"normal"},
				keywords = {"퀘", "하실", "입장퀘", "상급소환", "실리", "투기장", "나그", "나그란드"},
				excludekeywords = {"골팟", "올분", "참석", "길드", "하신", "명점", "쟁", "전장", "킬하실"},
			},
		},
	},
}

-- 모든 무시 키워드는 각단계 별로 별도로 제거 됩니다.
-- 즉, 다른 단계에서 사용한 키워드가 있다면 해당 단계에서 제거하는 것이 좋습니다.
-- 던전명 인식시 해당 문자열을 제거한후 던전명을 인식합니다. 오인식이 자주되는 키워드 위주로 추가하면 좋습니다.
-- 이를테면 도적의 키워드가 "도" 이고, 난이도 인식시 사용하는 키워드가 "도전" 이면, 직업 필터링에 "도전"을 추가하면 
-- 도전 모드는 정상적으로 인식되며 "도전" 을 도적으로 오인식하는 경우가 줄어듭니다.
-- 영어 사용시 대문자로만 적으세요. (자동으로 대문자 변환함)
FP_DUNGEON_IGNORE_KEYWORDS = {
	"할줄아",--줄아만 오분류
	"얼마나",--마나 무덤 오분류
}

-- 던전 이름 뒤에 다음 문자열이 기록되어 있으면 무시합니다.
-- 운다손, 갈레온손 같은 경우를 제거하기 위함입니다.
FP_DUNGEON_IGNORE_POSTFIX_KEYWORDS = {
	"손",--운다 손
	"뜸",--운다 뜸
	"없",--운다 없나요?
	"ㅅ"--운다 ㅅㅅ
}

-- 목록 툴팁에서 가독성에 영향을 주는 문자열을 사전 제거 합니다. 가능한 최소로 사용하세요.
FP_TOOLTIP_IGNORE_KEYWORDS = {
	-- 툴팁에는 이모티콘이 표시되지 않으므로 이모티콘 관련 문자들 제거
	"{해골}", "{별}", "{다이아몬드}", "{세모}", "{가위표}", "{동그라미}", "{달}", "{네모}", "{rt1}", "{rt2}", "{rt3}", "{rt4}", "{rt5}", "{rt6}", "{rt7}", "{rt8}"
}

-- 스팸 메시지 필터링 문자열
FP_GLOBAL_EXCLUDE_KEYWORDS = {
	"길드에서",
	"길드원",
	"길드는",
	"길원",
	"친목",
	"함께",
	"파밍",
	"렙업",
	"레벨업",
	"레벨링",
	"삽니다",
	"닌자",
	"먹튀",
}
